# frigate

![Version: 8.1.2](https://img.shields.io/badge/Version-8.1.2-informational?style=flat-square) ![AppVersion: 0.10.0-amd64](https://img.shields.io/badge/AppVersion-0.10.0--amd64-informational?style=flat-square)

NVR With Realtime Object Detection for IP Cameras

**This chart is not maintained by the upstream project and any issues with the chart should be raised [here](https://github.com/k8s-at-home/charts/issues/new/choose)**

## Source Code

* <https://github.com/blakeblackshear/frigate>

## Requirements

Kubernetes: `>=1.16.0-0`

## Dependencies

| Repository | Name | Version |
|------------|------|---------|
| https://library-charts.k8s-at-home.com | common | 4.4.2 |

## TL;DR

```console
helm repo add k8s-at-home https://k8s-at-home.com/charts/
helm repo update
helm install frigate k8s-at-home/frigate
```

## Installing the Chart

To install the chart with the release name `frigate`

```console
helm install frigate k8s-at-home/frigate
```

## Uninstalling the Chart

To uninstall the `frigate` deployment

```console
helm uninstall frigate
```

The command removes all the Kubernetes components associated with the chart **including persistent volumes** and deletes the release.

## Configuration

Read through the [values.yaml](./values.yaml) file. It has several commented out suggested values.
Other values may be used from the [values.yaml](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common/values.yaml) from the [common library](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common).

Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`.

```console
helm install frigate \
  --set env.TZ="America/New York" \
    k8s-at-home/frigate
```

Alternatively, a YAML file that specifies the values for the above parameters can be provided while installing the chart.

```console
helm install frigate k8s-at-home/frigate -f values.yaml
```

## Custom configuration

### Frigate database directory

It is recommended to set a separate database directory for Frigate.

For example:

```yaml
persistence:
  data:
    enabled: true
    mountPath: /data
    # ...
config: |
  # ...
  database:
    path: /data/frigate.db
  # ...
```

## Values

**Important**: When deploying an application Helm chart you can add more values from our common library chart [here](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common)

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| affinity | object | `{}` | Affinity constraint rules to place the Pod on a specific node. [[ref]](https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node/#affinity-and-anti-affinity) |
| configmap.config.data | object | see URL to default config | See [docs](https://blakeblackshear.github.io/frigate/) for more details. |
| configmap.config.enabled | bool | `true` | Store frigate configuration as a ConfigMap |
| env | object | See below | environment variables. See [docs](https://blakeblackshear.github.io/frigate/) for more details. |
| env.FRIGATE_RTSP_PASSWORD | string | empty | Set a RTSP password |
| env.TZ | string | `"UTC"` | Set the container timezone |
| image.pullPolicy | string | `"IfNotPresent"` | image pull policy |
| image.repository | string | `"blakeblackshear/frigate"` | image repository |
| image.tag | string | chart.appVersion | image tag |
| ingress.main | object | See values.yaml | Enable and configure ingress settings for the chart under this key. |
| persistence | object | See values.yaml | Configure persistence settings for the chart under this key. |
| persistence.cache | object | See values.yaml | Configure a temporary cache. See [docs](https://blakeblackshear.github.io/frigate/) for more details.. |
| persistence.usb | object | See values.yaml | Configure a hostPathMount to mount a USB device in the container. |
| resources | object | `{}` | Configure the resource requests and/or limits for the Pod |
| securityContext.privileged | bool | `false` | (bool) Privileged securityContext may be required if USB devices are accessed directly through the host machine |
| service | object | See values.yaml | Configures service settings for the chart. |

## Changelog

### Version 8.1.2

#### Added

N/A

#### Changed

* Upgraded `common` chart dependency to version 4.4.2

#### Fixed

N/A

### Older versions

A historical overview of changes can be found on [ArtifactHUB](https://artifacthub.io/packages/helm/k8s-at-home/frigate?modal=changelog)

## Support

- See the [Docs](https://docs.k8s-at-home.com/our-helm-charts/getting-started/)
- Open an [issue](https://github.com/k8s-at-home/charts/issues/new/choose)
- Ask a [question](https://github.com/k8s-at-home/organization/discussions)
- Join our [Discord](https://discord.gg/sTMX7Vh) community

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v0.1.1](https://github.com/k8s-at-home/helm-docs/releases/v0.1.1)
